==> ejc-sale-api-3.0.0-20220414.083315-35-sources.jar: com.ejianc.business.sale/salesorder/vo/CloseVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

public class CloseVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long productId; // 产品id
    private String productName; // 产品名称
    private Long worksiteId; // 工地id
    private String worksiteName; // 工地名称
    private Long projectId; // 工程id
    private String projectName; // 工程名称
    private Long customerManageId; // 客户管理档案id
    private String customerManageName; // 客户管理档案名称

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }

    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getCustomerManageId() {
        return customerManageId;
    }

    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }

    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }
}

==> ejc-sale-api-3.0.0-20220429.060214-66-sources.jar: com.ejianc.business.sale/salesorder/vo/CloseVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

public class CloseVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long productId; // 产品id
    private String productName; // 产品名称
    private Long worksiteId; // 工地id
    private String worksiteName; // 工地名称
    private Long projectId; // 工程id
    private String projectName; // 工程名称
    private Long customerManageId; // 客户管理档案id
    private String customerManageName; // 客户管理档案名称
    private BigDecimal thisQuantity; // 本次数量

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }

    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getCustomerManageId() {
        return customerManageId;
    }

    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }

    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }

    public BigDecimal getThisQuantity() {
        return thisQuantity;
    }

    public void setThisQuantity(BigDecimal thisQuantity) {
        this.thisQuantity = thisQuantity;
    }
}
